@@ -1,7 +1,8 @@
 #!/bin/sh
+export PATH='/usr/obj/hs-hashable-1.2.2.0/bin:/usr/bin:/bin:/usr/sbin:/sbin:/usr/local/bin:/usr/local/bin:/usr/X11R6/bin'
 echo 'name: hashable
-version: 1.1.2.5
-id: hashable-1.1.2.5-e0f2541518f84d3123a819112b4ffe20
+version: 1.2.2.0
+id: hashable-1.2.2.0-6aae2a5ae00dba4cc06a8e388409e9ed
 
 license: BSD3
 copyright:
@@ -21,25 +22,25 @@ author: Milan Straka <fox@ucw.cz>
 pkgpath: devel/hs-hashable
 exposed: True
 exposed-modules: Data.Hashable
-hidden-modules:
+hidden-modules: Data.Hashable.Class Data.Hashable.Generic
 trusted: False
-import-dirs: /usr/local/lib/ghc/hashable-1.1.2.5
-library-dirs: /usr/local/lib/ghc/hashable-1.1.2.5
-hs-libraries: HShashable-1.1.2.5
+import-dirs: /usr/local/lib/ghc/hashable-1.2.2.0
+library-dirs: /usr/local/lib/ghc/hashable-1.2.2.0
+hs-libraries: HShashable-1.2.2.0
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
 includes:
-depends: base-4.6.0.1-03845c6da2a0b3b4d0d49cc26c0cd3c0
-         bytestring-0.10.0.2-9e8b487747800a4255d6ff7915c5210f
-         ghc-prim-0.3.0.0-d5221a8c8a269b66ab9a07bdc23317dd
-         integer-gmp-0.5.0.0-2f15426f5b53fe4c6490832f9b20d8d7
-         text-0.11.3.1-06d227f06409a354e0c77a385328bada
+depends: base-4.7.0.2-e1c96ce41208f09c293083d78870d5a2
+         bytestring-0.10.4.0-84f2b632cefc94e5dfeafb660607fcbd
+         ghc-prim-0.3.1.0-a24f9c14c632d75b683d0f93283aea37
+         integer-gmp-0.5.1.0-26579559b3647acf4f01d5edd9491a46
+         text-1.1.0.0-72236c81391c0a9a303f37559690d8fe
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-hashable-1.1.2.5/html/hashable.haddock
-haddock-html: /usr/local/share/doc/hs-hashable-1.1.2.5/html
+haddock-interfaces: /usr/local/share/doc/hs-hashable-1.2.2.0/html/hashable.haddock
+haddock-html: /usr/local/share/doc/hs-hashable-1.2.2.0/html
 ' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
